function yvals = legEvalSignal( n_leg, coeffs, xvals)
%
% y = legEvalSignal( n_leg, coeffs, xvals)
% 
% Evaluate signal(s) in the space spanned by Legendre polynomials up to 
% degree n_leg.
%
% @param n_leg    maximum degree of Legendre polynomials
% @param coeffs   array of coefficients (first dimension corresponds to
%                 multiple signals, if any; second dimension has to have 
%                 at least size (n_leg+1)).
% @param xvals    Abscissa values where to evaluate signal(s).
%
% @return yvals   num_signal x num_xvals dimensional array with signal 
%                 vales.

  assert( size(coeffs,2) >= (n_leg+1));
  
  yvals = zeros( size( coeffs, 1), numel( xvals));
  for( n = 0 : n_leg)
    cdat = legendre( n, xvals, 'norm');
    yvals = yvals + (coeffs(:,n+1) * cdat(1,:));
  end
  
end