% Show approximations of different signals in fixed Legendre space
% Signal 1: Legendre signal with  higher n_leg.
% Signal 2: Spline signal with singularities.
% Signal 3: Signal in characteristic basis.

legInit;

%% low order approximation

n_leg = 4;

% for the Legendre polynomials the approximation has closed for solution
[fvals_leg, coeffs_leg] = signalLeg( xvals);
coeffs_leg = coeffs_leg(1:n_leg+1);
fvals_leg_rec = legEvalSignal( n_leg, coeffs_leg, xvals); 

% signal with Singularities
coeffs_sing = legApproximateSignal( n_leg, @signalSingularities);
fvals_sing_rec = legEvalSignal( n_leg, coeffs_sing', xvals); 
fvals_sing = signalSingularities( xvals);

% characteristic signal
coeffs_char = legApproximateSignal( n_leg, @signalCharacteristic);
fvals_char_rec = legEvalSignal( n_leg, coeffs_char', xvals); 
fvals_char = signalCharacteristic( xvals);

%% Plot results

legPreVisualization();

plot( xvals, fvals_leg, '-r', xvals, fvals_leg_rec, '--r');
plot( xvals, fvals_sing, '-b', xvals, fvals_sing_rec, '--b');
plot( xvals, fvals_char, '-c', xvals, fvals_char_rec, '--c');

legPostVisualization();

savePlot( h_fig, 'legPlotApproximations_a');


%% higher order approximation

n_leg = 20;

% for the Legendre polynomials the approximation has closed for solution
[fvals_leg, coeffs_leg] = signalLeg( xvals);
coeffs_leg = coeffs_leg(1:n_leg+1);
fvals_leg_rec = legEvalSignal( n_leg, coeffs_leg, xvals); 

% signal with Singularities
coeffs_sing = legApproximateSignal( n_leg, @signalSingularities);
fvals_sing_rec = legEvalSignal( n_leg, coeffs_sing', xvals); 
fvals_sing = signalSingularities( xvals);

% characteristic signal
coeffs_char = legApproximateSignal( n_leg, @signalCharacteristic);
fvals_char_rec = legEvalSignal( n_leg, coeffs_char', xvals); 
fvals_char = signalCharacteristic( xvals);

%% Plot results

legPreVisualization();

plot( xvals, fvals_leg, '-r', xvals, fvals_leg_rec, '--r');
plot( xvals, fvals_sing, '-b', xvals, fvals_sing_rec, '--b');
plot( xvals, fvals_char, '-c', xvals, fvals_char_rec, '--c');

legPostVisualization();

savePlot( h_fig, 'legPlotApproximations_b');


