% Plot basis expansion for Legendre polynomials

legInit;

% generate values
vals_leg_polys = zeros( n_leg + 1, numel(xvals));

for( n = 0 : n_leg)
  cdat = legendre( n, xvals, 'norm');
  vals_leg_polys(n+1,:) = cdat(1,:);
end

%

% random signals (coefficients for n_leg = 4)
% fix coefficients for reproducibility
coeffs_1 = [-0.0065    0.0092   -0.0238    0.5752  -0.0681];
coeffs_2 = [0.0228   -0.0424   -0.0167    -1.1176    0.0520];

% generate signal samples
sig_vals_1 = legEvalSignal( n_leg, coeffs_1, xvals);
sig_vals_2 = legEvalSignal( n_leg, coeffs_2, xvals);

%% Visualization

% visualize
legPreVisualization;

% plot Legendre basis functions
for( n = 0 : n_leg)  
  col = cols(n+1,:);
  col( find( col == 0.0)) = 0.95;
  plot( xvals, vals_leg_polys(n+1,:), '-', 'Color', col); 
  col
end

% plot signal
plot( xvals, sig_vals_1, '-r');
plot( xvals, sig_vals_2, '-b');

% set parameters for saving
legPostVisualization;
% save image
savePlot( h_fig, 'legPlotInnerProduct_a');

disp( sprintf( 'dot(coeffs_1,coeffs_2) = %f', dot(coeffs_1,coeffs_2)));

% 
  
% random signals (coefficients for n_leg = 4)
% fix coefficients for reproducibility
coeffs_1 = [0.0630    0.0330   -0.0034   0.8261   -0.0109];
coeffs_2 = [0.0763    0.0233   -0.0105    0.0313   -1.0298];

% generate signal samples
sig_vals_1 = legEvalSignal( n_leg, coeffs_1, xvals);
sig_vals_2 = legEvalSignal( n_leg, coeffs_2, xvals);

% plot 

legPreVisualization;

% plot Legendre basis functions
for( n = 0 : n_leg)  
  col = cols(n+1  ,:);
  col( find( col == 0.0)) = 0.95;
  plot( xvals, vals_leg_polys(n+1,:), '-', 'Color', col);      
end

% plot signal
plot( xvals, sig_vals_1, '-r');
plot( xvals, sig_vals_2, '-b');

% set parameters for saving
legPostVisualization;
% save image
savePlot( h_fig, 'legPlotInnerProduct_b');

disp( sprintf( 'dot(coeffs_1,coeffs_2) = %f', dot(coeffs_1,coeffs_2)));

