% Plot reproducing kernels at three points in [-1,1]

legInit;

delta = 2.0 / (n_leg+1);
lambdas = [-1.0 : delta : 1.0];
lambdas = lambdas(1:end-1) + delta / 2.0;

% generate values
K = zeros( n_leg + 1, n_leg+1);

% construct kernel matrix: 
% - each column is fixed basis function
% - each row is one fixed lambda
for( n = 0 : n_leg)
  coeffs = legendre( n, lambdas, 'norm');
  K(:,n+1) = coeffs(1,:)';  
end

% values of kernel and dual kernel functions
vals_k = zeros( n_leg+1, numel(xvals));

for( i = 1 : numel(lambdas))
  vals_k(i,:) = legEvalSignal( n_leg, K(i,:), xvals);
end

%%

% random signal
coeffs = [0.7097    0.1458    0.0989    0.7938   -0.4022];

sig = legEvalSignal( n_leg, coeffs, xvals);

f_lambdas = K * coeffs';

%% visualize

legPreVisualization;

% plot basis functions
for( i = 1 : numel(lambdas))
  
  col = cols(i,:);
  col( find( col == 0.0)) = 0.8;
  plot( lambdas(i), 0.0, 'x', 'MarkerSize', 10, 'Color', col);
  plot( xvals, vals_k(i,:), '-', 'Color', col);

end

plot( xvals, sig, '-r');
for( i = 1 : numel(lambdas))
  plot( lambdas(i), f_lambdas(i), 'xr', 'MarkerSize', 15);
end

legPostVisualization;
ylim( [-3.0, 3.0])

savePlot( h_fig, 'legPlotKernelMatrix');
