% optimize sampling points and plot development of location, also 
% analyze difference in reconstruction error

legInit;

% construct initial sampling points
% lambdas_init = halton( n_leg+1, 1);
% lambdas_init = rand( n_leg+1, 1);
% lambdas_init = sort( (2.0 * lambdas_init) - 1.0)';
% Fix points for reproducibility
lambdas_init = [-0.8866, -0.6438, -0.3283, -0.2807, 0.0438];


% initial condition number
cond_init = cond( legKernelMatrix( n_leg, lambdas_init));

% variable to retain optimization history
global history;
history.en = [];
history.lambdas = lambdas_init;

% generate lower and upper bounds for locations for optimization
lb = -1.0 * ones( size(lambdas_init));
ub = ones( size(lambdas_init));

% use active set algorithm 
options = optimset( 'Algorithm', 'active-set', ...
                    'OutputFcn', @legOptProgressCallback, ...
                    'Display', 'iter', ...
                    'TolFun', 1e-12, ...
                    'TolX', 1e-10);

% construct the energy function that only has one parameter
enFunc = @(lambdas)legEnKernelMatrix( lambdas, n_leg);

% run optimization
[lambdas_opt] = fmincon( enFunc, lambdas_init, ...
                         [], [], [], [], ...
                         lb, ub, [], ...
                         options );

% 
cond_opt = cond( legKernelMatrix( n_leg, lambdas_opt));

%% Visualization convergence

legPreVisualization
plot( [0:numel(history.en)-1], history.en + 1.0, '-xr');
legPostVisualization;
xlim( [0, numel(history.en)-1]);
ylim( [0, max(history.en) + 1.0]);
set( gca, 'YScale', 'log');
set(gca,'YTick',[10^0, 10^1, 10^2, 10^3])

savePlot( h_fig, 'legPlotOptimization_convergence');

%% Visualization point evolution

cols_opt = [ 1.0, 0.0, 0.0; 
             0.0, 1.0, 0.0;
             0.0, 0.0, 1.0;
             0.0, 0.0, 0.0;
             0.75, 0.0, 0.75];
cols_opt_s = [ 1.0, 0.8, 0.8; 
               0.8, 1.0, 0.8;
               0.8, 0.8, 1.0;
               0.8, 0.8, 0.8;
               0.75, 0.8, 0.75];

% plot first steps, the remaining optimization is very flat
j = 1;
for( i = [1 : 2 : 10])

  lambdas = history.lambdas(i,:);
  K = legKernelMatrix( n_leg, lambdas);
  
  legPreVisualization;
  % avoid visibility issue by drawing lines first
  for( a = 1 : numel(lambdas))
    kernel = legEvalSignal( n_leg, K(a,:), xvals);
    plot( xvals, kernel, '-', 'Color', cols_opt_s(a,:));
  end
  for( a = 1 : numel(lambdas))
    plot( lambdas(a), 0.0, 'x', ...
          'Color', cols_opt(a,:), 'MarkerSize', 15, 'LineWidth', 1.25);
  end
  legPostVisualization;
  ylim( [-3.0, 3.0]);
  
  savePlot( h_fig, ['legPlotOptimization_progress_', num2str(j)]);
  j = j + 1;
  
  pause(0.5);
  
end

lambdas = history.lambdas(end,:);
K = legKernelMatrix( n_leg, lambdas);

legPreVisualization;
for( a = 1 : numel(lambdas))
  kernel = legEvalSignal( n_leg, K(a,:), xvals);
  plot( xvals, kernel, '-', 'Color', cols_opt_s(a,:));
end
for( a = 1 : numel(lambdas))
  plot( lambdas(a), 0.0, 'x', ...
        'Color', cols_opt(a,:), 'MarkerSize', 15, 'LineWidth', 1.25);
end
legPostVisualization;
ylim( [-3.0, 3.0]);

savePlot( h_fig, 'legPlotOptimization_progress_final');
 