% Quadrature rule for the space 

legInit;

optimized = 1;

if( 1 == optimized)
  % generated with legPlotOptimization.m
  lambdas = [-0.8810   -0.5428   -0.0000    0.5428    0.8810]
else
  lambdas = [-0.8866, -0.6438, -0.3283, -0.2807, 0.0438]
end

% generate values
K = zeros( n_leg + 1, n_leg+1);

% construct kernel matrix: 
% - each column is fixed basis function
% - each row is one fixed lambda
for( n = 0 : n_leg)
  coeffs = legendre( n, lambdas, 'norm');
  K(:,n+1) = coeffs(1,:)';  
end

% sampling matrix
% - i-th column is formed by basis function coefficients for i-th dual
%   basis function 
S = inv(K);

% Legendre polynomials are a special case since all but the first basis
% function vanishes
% The constant is the integral of the normalized P_0 function
% Note that to compute the quadrature weights we would not have to compute
% the full inverse since only the first row is relevant 
weights = sqrt(2.0) * S(1,:);

% values of kernel and dual kernel functions
vals_k = zeros( n_leg+1, numel(xvals));
vals_kd = zeros( n_leg+1, numel(xvals));

for( i = 1 : numel(lambdas))
  vals_k(i,:) = legEvalSignal( n_leg, K(i,:), xvals);
  vals_kd(i,:) = legEvalSignal( n_leg, S(:,i)', xvals);
end

%% Verify quadrature for some special cases

err = 0.0;
for( i = 1 : n_leg)
  
  coeffs = zeros( 1, n_leg+1);
  coeffs(i+1) = 1;
  
  f_vals = legEvalSignal( n_leg, coeffs, lambdas);
  
  integral = dot( f_vals, weights);
  
  % integral vanishes for all but the first Legendre polynomial
  err = integral;
  
end
err = integral / n_leg;

disp( sprintf( 'Error integrals = %e', err));


%% visualize

legPreVisualization;

if( 1 == optimized)
  scaling_plot = 1.0;
else
  scaling_plot = 1.0;
end

% plot corresponding reproducing points
for( i = 1 : numel(lambdas))
  
  col = cols(i,:);
  col( find( col == 0.0)) = 0.8;
  plot( lambdas(i), 0.0, 'x', 'MarkerSize', 10, 'Color', col);
  plot( xvals, vals_kd(i,:), '-', 'Color', col);
  
  plot( [lambdas(i), lambdas(i)], [0.0, scaling_plot*weights(i)], '-o', ...
          'Color', cols(i,:), 'LineWidth', 1.25);

end

legPostVisualization;
ylim( [min( 0.0, 1.25 * min(weights)), max( 1.1, 1.25 * max(weights))]);

if( 1 == optimized)
  savePlot( h_fig, 'legPlotQuadratureOptimized_a');
else
  savePlot( h_fig, 'legPlotQuadratureOptimized_b');
end
  
% legPostVisualizationTight;
% ylim( [min( 0.0, 1.25 * min(weights)), max( 1.1, 1.25 * max(weights))]);
% 
% if( 1 == optimized)
%   savePlot( h_fig, 'legPlotQuadratureOptimizedTight_a');
% else
%   savePlot( h_fig, 'legPlotQuadratureOptimizedTight_b');
% end
%   

