% Demonstration how oversampling an optimization affects the approximation
% power using RKHS.

legInit;   
n_leg_in = 5;

% random input signal
% coeffs_in = 0.5 * randn( 1, n_leg_approx+1);
% Fix coefficients for reproducibility
coeffs_in = [0.5000, -0.8321, -0.2950, -0.1390, 0.2114, -0.8351];

% critically sampled
lambdas_cs = [-0.8000, -0.4000, 0.0000, 0.4000, 0.8000];
% oversampled
lambdas_os = [-0.9416, -0.8290, -0.7652, -0.4750, -0.4066, ...
              -0.3624, -0.1517, 0.0157, 0.6020, 0.8577];
% oversampled and optimized
lambdas_opt = [-0.9197, -0.6570, -0.5523, -0.2614, -0.1292, ...
               0.1557, 0.2259, 0.5768, 0.6408, 0.9204];

% compute approximations
f_cs = legRKApproximate( n_leg_in, n_leg, lambdas_cs, coeffs_in, xvals);
f_os = legRKApproximate( n_leg_in, n_leg, lambdas_os, coeffs_in, xvals);
f_opt = legRKApproximate( n_leg_in, n_leg, lambdas_opt, coeffs_in, xvals);

% compute errors
err_cs = norm( coeffs_in(1:end-1) - f_cs.coeffs);
err_os = norm( coeffs_in(1:end-1) - f_os.coeffs);
err_opt = norm( coeffs_in(1:end-1) - f_opt.coeffs);

%% Visualization

% input signal
f = legEvalSignal( n_leg_in, coeffs_in, xvals);
% L_2 optimal approximation
f_ideal = legEvalSignal( n_leg, coeffs_in, xvals);

legPreVisualization;
plot( xvals, f, '--', 'Color', [0.7, 0.7, 0.7]);
plot( xvals, f_cs.vals, '-', 'Color', [0.5, 0.5, 1.0]);
plot( xvals, f_os.vals, '-', 'Color', [0.5, 1.0, 0.5]);
plot( xvals, f_ideal, '-k');
plot( xvals, f_opt.vals, '-r');
legPostVisualization;

savePlot( h_fig, 'legPlotRKApproximation');

% plot condition numbers and error rates
disp( sprintf( 'cond = %.2f , %.2f , %.2f', ...
                f_cs.condK, f_os.condK, f_opt.condK));
disp( sprintf( 'err = %.2f , %.2f , %.2f', ...
                err_cs, err_os, err_opt));