% Plot reproducing kernels at three points in [-1,1]

legInit;

% locations of reproducing point
%p = haltonset( 1, 'Skip', 1e3, 'Leap', 1e2);
%p = scramble( p, 'RR2');
% lambdas = net( p, n_leg+1);

lambdas = halton( 5, 1);
lambdas = sort( (0.35 * lambdas) - 0.2);

% generate values
K = zeros( n_leg + 1, n_leg+1);

% construct kernel matrix: 
% - each column is fixed basis function
% - each row is one fixed lambda
for( n = 0 : n_leg)
  coeffs = legendre( n, lambdas, 'norm');
  K(:,n+1) = coeffs(1,:)';  
end

% sampling matrix
% - i-th column is formed by basis function coefficients for i-th dual
%   basis function 
S = inv(K);

% values of kernel and dual kernel functions
vals_k = zeros( n_leg+1, numel(xvals));
vals_kd = zeros( n_leg+1, numel(xvals));

for( i = 1 : numel(lambdas))
  vals_k(i,:) = legEvalSignal( n_leg, K(i,:), xvals);
  vals_kd(i,:) = legEvalSignal( n_leg, S(:,i)', xvals);
end

%% visualize

legPreVisualization;

% plot basis functions
for( i = 1 : numel(lambdas))
  plot( xvals, vals_k(i,:), '-', 'Color', cols(i,:));
end
% plot corresponding reproducing points
for( i = 1 : numel(lambdas))
  plot( lambdas(i), 0.0, 'x', 'MarkerSize', 15, 'Color', cols(i,:));
end

legPostVisualization;
ylim( [-3.0, 3.0])

savePlot( h_fig, 'legPlotRKBasisBad_a');

%

legPreVisualization;
plot( [0.0, 0.0], [-30000.0, 30000.0], 'Color', [0.8, 0.8, 0.8]);

% plot basis functions
for( i = 1 : numel(lambdas))
  plot( xvals, abs(vals_kd(i,:)), '-', 'Color', cols(i,:));
end

legPostVisualization;
ylim( [-30000.0, 30000.0]);
% set( gca, 'YScale', 'log');

savePlot( h_fig, 'legPlotRKBasisBad_b');

% 

legPreVisualization;
plot( [0.0, 0.0], [-30.0, 30.0], 'Color', [0.8, 0.8, 0.8]);

% plot basis functions
for( i = 1 : numel(lambdas))
  plot( xvals, abs(vals_kd(i,:)), '-', 'Color', cols(i,:));
end

legPostVisualization;
ylim( [-30.0, 30.0]);

savePlot( h_fig, 'legPlotRKBasisBad_c');
