% Plot reproducing kernels at three points in [-1,1]

legInit;

% locations of reproducing kernels
lambdas = [-0.8, 0.1, 0.5];

% generate values
vals_rks = zeros( numel( lambdas), numel(xvals));

for( n = 0 : n_leg)
  
  % value of basis functions
  cdat = legendre( n, xvals, 'norm');
  % basis function coefficients
  coeffs = legendre( n, lambdas, 'norm');
  
  % accumulate contribution by current basis function
  vals_rks = vals_rks + coeffs(1,:)' * cdat(1,:);
  
end

% visualize
legPreVisualization;

% plot reproducing kernels
plot( xvals, vals_rks(1,:), ['-', 'r']);
plot( xvals, vals_rks(2,:), ['-', 'g']);
plot( xvals, vals_rks(3,:), ['-', 'b']);

% plot corresponding lambads
plot( lambdas(1), 0.0, 'xr', 'MarkerSize', 15);
plot( lambdas(2), 0.0, 'xg', 'MarkerSize', 15);
plot( lambdas(3), 0.0, 'xb', 'MarkerSize', 15);

legPostVisualization;
savePlot( h_fig, 'legPlotReproducingKernel');

% legPostVisualizationTight;
% ylim( [-2.5, 2.5])
% savePlot( h_fig, 'legPlotReproducingKernelTight');
