% Plot reproducing kernels at three points in [-1,1]

legInit;

% locations of reproducing point
lambda = 0.5;

% generate values
vals_rk = zeros( 1, numel(xvals));
coeffs_rk = zeros( 1, n_leg+1);

for( n = 0 : n_leg)
  
  % value of basis functions
  cdat = legendre( n, xvals, 'norm');
  % basis function coefficients
  coeffs = legendre( n, lambda, 'norm');
  coeffs_rk(n+1) = coeffs(1);
  
  % accumulate contribution by current basis function
  vals_rk = vals_rk + coeffs(1)' * cdat(1,:);
  
end

% generate random signal 
% coeffs_rand = 0.5 * randn( 1, n_leg + 1);
% fix coefficients for reproducibility
coeffs_rand = [0.1162    0.2132   -0.1864   -0.1182    1.0118];
sig = legEvalSignal( n_leg, coeffs_rand, xvals);

% evaluate inner product
ip = dot( coeffs_rk, coeffs_rand);


% coeffs_rand_2 = 0.5 * randn( 1, 10 + 1);
% Fix coefficients for reproducibility
coeffs_rand_2 = [ 0.7025, 0.5171, 0.1458, -0.3888, 0.2833, -0.6913, ...
                  0.1222, 0.4042, 0.1065, 0.4398, 1.0194];
sig_2 = legEvalSignal( 10, coeffs_rand_2, xvals);

ip_2 = dot( coeffs_rk, coeffs_rand_2(1:numel(coeffs_rk)));


%% visualize

legPreVisualization;

% plot reproducing kernels
plot( xvals, vals_rk, ['-', 'b']);

% plot random signal
plot( xvals, sig, ['-', 'r']);
% plot reproducing property
plot( lambda, ip, 'xr', 'MarkerSize', 15);

% plot random signal
plot( xvals, sig_2, ['-', 'c']);
% plot reproducing property
plot( lambda, ip_2, 'xc', 'MarkerSize', 15);

legPostVisualization;
ylim( [-2.5, 2.5])

savePlot( h_fig, 'legPlotReproducingProperty');
